#Python 3.7
import numpy as np
import matplotlib.pyplot as plt
from numpy import sqrt

# période et longueur du pendule ainsi que leurs incertitudes
T = 1.4900
L = 0.548
u_T = 0.0015
u_L = 0.002/sqrt(3)    # on divise la précision par racine de 3

# nombre de simulations que l'on veut effectuer
N = 1000

# calculs avec une distribution de probabilité normale
L_al = np.random.normal(L,u_L,N)
T_al = np.random.normal(T,u_T,N)
g = 4*np.pi**2*L_al/T_al**2

# Calcul et affichage moyenne et écart-type
g_moy = np.mean(g)
u_g = np.std(g,ddof=1)
print("g moyen vaut {:.4f} m/s²".format(g_moy))
print("L'écart-type sur g moyen vaut {:.4f} m/s²".format(u_g))

# Détermination de g et de l'incertitude-type sur g
#par formule de propagation à partir des incertitudes relatives
g_bis = 4*np.pi**2*L/T**2
u_g_bis = g_bis*sqrt((u_L/L)**2+(2*u_T/T)**2)
print("g vaut {:.4f} m/s²".format(g_bis))
print("L'incertitude-type sur g par composition vaut {:.4f} m/s²".format(u_g_bis))

plt.hist(g,bins='rice')
plt.figtext (0.9,0.85,"g calculé : {:.4f} m/s2".format(g_bis),color='r',horizontalalignment='right')
plt.figtext (0.9,0.8,"u(g) par propagation : {:.4f} m/s2".format(u_g_bis),color='r',horizontalalignment='right')
plt.figtext (0.5,0.25,"simulation Monte-Carlo",color='black',horizontalalignment='center')
plt.figtext (0.5,0.2,"moyenne : {:.4f} m/s2".format(g_moy),color='black',horizontalalignment='center')
plt.figtext (0.5,0.15,"écart-type : {:.4f} m/s2".format(u_g),color='black',horizontalalignment='center')
plt.show()



